@@ -21,7 +21,7 @@ import twitter4j.internal.async.Dispatcher;
 import twitter4j.internal.http.HttpResponse;
 import twitter4j.internal.org.json.JSONException;
 import twitter4j.internal.org.json.JSONObject;
-import twitter4j.internal.util.ParseUtil;
+import twitter4j.internal.json.z_T4JInternalParseUtil;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -32,7 +32,7 @@ import java.io.InputStream;
  * @author Yusuke Yamamoto - yusuke at mac.com
  * @since Twitter4J 2.1.2
  */
-class StatusStreamImpl extends AbstractStreamImplementation implements StatusStream {
+class StatusStreamImpl extends StatusStreamBase {
     /*package*/
 
     StatusStreamImpl(Dispatcher dispatcher, InputStream stream, Configuration conf) throws IOException {
@@ -46,25 +46,15 @@ class StatusStreamImpl extends AbstractStreamImplementation implements StatusStr
 
     protected String line;
 
-    protected StreamListener[] listeners;
-
-    /**
-     * Reads next status from this stream.
-     *
-     * @param listener a StatusListener implementation
-     * @throws TwitterException      when the end of the stream has been reached.
-     * @throws IllegalStateException when the end of the stream had been reached.
-     */
+    protected static final RawStreamListener[] EMPTY = new RawStreamListener[0];
+    @Override
     public void next(StatusListener listener) throws TwitterException {
-        StreamListener[] list = new StreamListener[1];
-        list[0] = listener;
-        this.listeners = list;
-        handleNextElement();
+        handleNextElement(new StatusListener[]{listener}, EMPTY);
     }
 
-    public void next(StreamListener[] listeners) throws TwitterException {
-        this.listeners = listeners;
-        handleNextElement();
+    @Override
+    public void next(StreamListener[] listeners, RawStreamListener[] rawStreamListeners) throws TwitterException {
+        handleNextElement(listeners, rawStreamListeners);
     }
 
     protected String parseLine(String line) {
@@ -73,45 +63,59 @@ class StatusStreamImpl extends AbstractStreamImplementation implements StatusStr
     }
 
     @Override
-    protected void onStatus(JSONObject json) throws TwitterException {
+    protected void onMessage(String rawString, RawStreamListener[] listeners) throws TwitterException {
+        for (RawStreamListener listener : listeners) {
+            listener.onMessage(rawString);
+        }
+    }
+
+    @Override
+    protected void onStatus(JSONObject json, StreamListener[] listeners) throws TwitterException {
         for (StreamListener listener : listeners) {
             ((StatusListener) listener).onStatus(asStatus(json));
         }
     }
 
     @Override
-    protected void onDelete(JSONObject json) throws TwitterException, JSONException {
+    protected void onDelete(JSONObject json, StreamListener[] listeners) throws TwitterException, JSONException {
         for (StreamListener listener : listeners) {
             JSONObject deletionNotice = json.getJSONObject("delete");
             if (deletionNotice.has("status")) {
                 ((StatusListener) listener).onDeletionNotice(new StatusDeletionNoticeImpl(deletionNotice.getJSONObject("status")));
             } else {
                 JSONObject directMessage = deletionNotice.getJSONObject("direct_message");
-                ((UserStreamListener) listener).onDeletionNotice(ParseUtil.getLong("id", directMessage)
-                        , ParseUtil.getLong("user_id", directMessage));
+                ((UserStreamListener) listener).onDeletionNotice(z_T4JInternalParseUtil.getLong("id", directMessage)
+                        , z_T4JInternalParseUtil.getLong("user_id", directMessage));
             }
         }
     }
 
     @Override
-    protected void onLimit(JSONObject json) throws TwitterException, JSONException {
+    protected void onLimit(JSONObject json, StreamListener[] listeners) throws TwitterException, JSONException {
         for (StreamListener listener : listeners) {
-            ((StatusListener) listener).onTrackLimitationNotice(ParseUtil.getInt("track", json.getJSONObject("limit")));
+            ((StatusListener) listener).onTrackLimitationNotice(z_T4JInternalParseUtil.getInt("track", json.getJSONObject("limit")));
         }
     }
 
     @Override
-    protected void onScrubGeo(JSONObject json) throws TwitterException, JSONException {
+    protected void onStallWarning(JSONObject json, StreamListener[] listeners) throws TwitterException, JSONException {
+        for (StreamListener listener : listeners) {
+            ((StatusListener) listener).onStallWarning(new StallWarning(json));
+        }
+    }
+
+    @Override
+    protected void onScrubGeo(JSONObject json, StreamListener[] listeners) throws TwitterException, JSONException {
         JSONObject scrubGeo = json.getJSONObject("scrub_geo");
         for (StreamListener listener : listeners) {
-            ((StatusListener) listener).onScrubGeo(ParseUtil.getLong("user_id", scrubGeo)
-                    , ParseUtil.getLong("up_to_status_id", scrubGeo));
+            ((StatusListener) listener).onScrubGeo(z_T4JInternalParseUtil.getLong("user_id", scrubGeo)
+                    , z_T4JInternalParseUtil.getLong("up_to_status_id", scrubGeo));
         }
 
     }
 
     @Override
-    public void onException(Exception e) {
+    public void onException(Exception e, StreamListener[] listeners) {
         for (StreamListener listener : listeners) {
             listener.onException(e);
         }
