@@ -23,7 +23,7 @@ import twitter4j.internal.http.HttpClientWrapper;
 import twitter4j.internal.http.HttpParameter;
 import twitter4j.internal.http.HttpRequest;
 import twitter4j.internal.logging.Logger;
-import twitter4j.internal.util.T4JInternalStringUtil;
+import twitter4j.internal.util.z_T4JInternalStringUtil;
 
 import javax.crypto.Mac;
 import javax.crypto.spec.SecretKeySpec;
@@ -31,11 +31,7 @@ import java.io.UnsupportedEncodingException;
 import java.net.URLDecoder;
 import java.security.InvalidKeyException;
 import java.security.NoSuchAlgorithmException;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collections;
-import java.util.List;
-import java.util.Random;
+import java.util.*;
 
 /**
  * @author Yusuke Yamamoto - yusuke at mac.com
@@ -65,12 +61,13 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
         this.conf = conf;
         http = new HttpClientWrapper(conf);
         setOAuthConsumer(conf.getOAuthConsumerKey(), conf.getOAuthConsumerSecret());
-        if (null != conf.getOAuthAccessToken() && null != conf.getOAuthAccessTokenSecret()) {
+        if (conf.getOAuthAccessToken() != null && conf.getOAuthAccessTokenSecret() != null) {
             setOAuthAccessToken(new AccessToken(conf.getOAuthAccessToken(), conf.getOAuthAccessTokenSecret()));
         }
     }
 
     // implementations for Authorization
+    @Override
     public String getAuthorizationHeader(HttpRequest req) {
         return generateAuthorizationHeader(req.getMethod().name(), req.getURL(), req.getParameters(), oauthToken);
     }
@@ -84,8 +81,9 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
     /**
      * #{inheritDoc}
      */
+    @Override
     public boolean isEnabled() {
-        return null != oauthToken && oauthToken instanceof AccessToken;
+        return oauthToken != null && oauthToken instanceof AccessToken;
     }
 
     // implementation for OAuthSupport interface
@@ -93,6 +91,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
     /**
      * {@inheritDoc}
      */
+    @Override
     public RequestToken getOAuthRequestToken() throws TwitterException {
         return getOAuthRequestToken(null, null);
     }
@@ -100,6 +99,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
     /**
      * {@inheritDoc}
      */
+    @Override
     public RequestToken getOAuthRequestToken(String callbackURL) throws TwitterException {
         return getOAuthRequestToken(callbackURL, null);
     }
@@ -107,6 +107,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
     /**
      * {@inheritDoc}
      */
+    @Override
     public RequestToken getOAuthRequestToken(String callbackURL, String xAuthAccessType) throws TwitterException {
         if (oauthToken instanceof AccessToken) {
             throw new IllegalStateException("Access token already available.");
@@ -125,6 +126,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
     /**
      * {@inheritDoc}
      */
+    @Override
     public AccessToken getOAuthAccessToken() throws TwitterException {
         ensureTokenIsAvailable();
         if (oauthToken instanceof AccessToken) {
@@ -137,6 +139,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
     /**
      * {@inheritDoc}
      */
+    @Override
     public AccessToken getOAuthAccessToken(String oauthVerifier) throws TwitterException {
         ensureTokenIsAvailable();
         oauthToken = new AccessToken(http.post(conf.getOAuthAccessTokenURL()
@@ -147,6 +150,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
     /**
      * {@inheritDoc}
      */
+    @Override
     public AccessToken getOAuthAccessToken(RequestToken requestToken) throws TwitterException {
         this.oauthToken = requestToken;
         return getOAuthAccessToken();
@@ -155,6 +159,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
     /**
      * {@inheritDoc}
      */
+    @Override
     public AccessToken getOAuthAccessToken(RequestToken requestToken, String oauthVerifier) throws TwitterException {
         this.oauthToken = requestToken;
         return getOAuthAccessToken(oauthVerifier);
@@ -163,12 +168,13 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
     /**
      * {@inheritDoc}
      */
+    @Override
     public AccessToken getOAuthAccessToken(String screenName, String password) throws TwitterException {
         try {
             String url = conf.getOAuthAccessTokenURL();
             if (0 == url.indexOf("http://")) {
                 // SSL is required
-                // @see http://apiwiki.twitter.com/Twitter-REST-API-Method%3A-oauth-access_token-for-xAuth
+                // @see https://dev.twitter.com/docs/oauth/xauth
                 url = "https://" + url.substring(7);
             }
             oauthToken = new AccessToken(http.post(url, new HttpParameter[]{
@@ -185,6 +191,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
     /**
      * {@inheritDoc}
      */
+    @Override
     public void setOAuthAccessToken(AccessToken accessToken) {
         this.oauthToken = accessToken;
     }
@@ -210,7 +217,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
         oauthHeaderParams.add(new HttpParameter("oauth_timestamp", timestamp));
         oauthHeaderParams.add(new HttpParameter("oauth_nonce", nonce));
         oauthHeaderParams.add(new HttpParameter("oauth_version", "1.0"));
-        if (null != otoken) {
+        if (otoken != null) {
             oauthHeaderParams.add(new HttpParameter("oauth_token", otoken.getToken()));
         }
         List<HttpParameter> signatureBaseParams = new ArrayList<HttpParameter>(oauthHeaderParams.size() + params.length);
@@ -219,7 +226,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
             signatureBaseParams.addAll(toParamList(params));
         }
         parseGetParameters(url, signatureBaseParams);
-        StringBuffer base = new StringBuffer(method).append("&")
+        StringBuilder base = new StringBuilder(method).append("&")
                 .append(HttpParameter.encode(constructRequestURL(url))).append("&");
         base.append(HttpParameter.encode(normalizeRequestParameters(signatureBaseParams)));
         String oauthBaseString = base.toString();
@@ -230,7 +237,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
         oauthHeaderParams.add(new HttpParameter("oauth_signature", signature));
 
         // http://oauth.net/core/1.0/#rfc.section.9.1.1
-        if (null != realm) {
+        if (realm != null) {
             oauthHeaderParams.add(new HttpParameter("realm", realm));
         }
         return "OAuth " + encodeParameters(oauthHeaderParams, ",", true);
@@ -239,10 +246,10 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
     private void parseGetParameters(String url, List<HttpParameter> signatureBaseParams) {
         int queryStart = url.indexOf("?");
         if (-1 != queryStart) {
-            String[] queryStrs = T4JInternalStringUtil.split(url.substring(queryStart + 1), "&");
+            String[] queryStrs = z_T4JInternalStringUtil.split(url.substring(queryStart + 1), "&");
             try {
                 for (String query : queryStrs) {
-                    String[] split = T4JInternalStringUtil.split(query, "=");
+                    String[] split = z_T4JInternalStringUtil.split(query, "=");
                     if (split.length == 2) {
                         signatureBaseParams.add(
                                 new HttpParameter(URLDecoder.decode(split[0],
@@ -283,7 +290,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
         oauthHeaderParams.add(new HttpParameter("oauth_timestamp", timestamp));
         oauthHeaderParams.add(new HttpParameter("oauth_nonce", nonce));
         oauthHeaderParams.add(new HttpParameter("oauth_version", "1.0"));
-        if (null != oauthToken) {
+        if (oauthToken != null) {
             oauthHeaderParams.add(new HttpParameter("oauth_token", oauthToken.getToken()));
         }
 
@@ -291,7 +298,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
         signatureBaseParams.addAll(oauthHeaderParams);
         parseGetParameters(url, signatureBaseParams);
 
-        StringBuffer base = new StringBuffer(method).append("&")
+        StringBuilder base = new StringBuilder(method).append("&")
                 .append(HttpParameter.encode(constructRequestURL(url))).append("&");
         base.append(HttpParameter.encode(normalizeRequestParameters(signatureBaseParams)));
 
@@ -365,21 +372,21 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
      * @return normalized and concatenated parameters
      * @see <a href="http://oauth.net/core/1.0#rfc.section.9.1.1">OAuth Core - 9.1.1.  Normalize Request Parameters</a>
      */
-    public static String normalizeRequestParameters(HttpParameter[] params) {
+    static String normalizeRequestParameters(HttpParameter[] params) {
         return normalizeRequestParameters(toParamList(params));
     }
 
-    public static String normalizeRequestParameters(List<HttpParameter> params) {
+    static String normalizeRequestParameters(List<HttpParameter> params) {
         Collections.sort(params);
         return encodeParameters(params);
     }
 
-    public static String normalizeAuthorizationHeaders(List<HttpParameter> params) {
+    static String normalizeAuthorizationHeaders(List<HttpParameter> params) {
         Collections.sort(params);
         return encodeParameters(params);
     }
 
-    public static List<HttpParameter> toParamList(HttpParameter[] params) {
+    static List<HttpParameter> toParamList(HttpParameter[] params) {
         List<HttpParameter> paramList = new ArrayList<HttpParameter>(params.length);
         paramList.addAll(Arrays.asList(params));
         return paramList;
@@ -396,7 +403,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
     }
 
     public static String encodeParameters(List<HttpParameter> httpParams, String splitter, boolean quot) {
-        StringBuffer buf = new StringBuffer();
+        StringBuilder buf = new StringBuilder();
         for (HttpParameter param : httpParams) {
             if (!param.isFile()) {
                 if (buf.length() != 0) {
@@ -434,7 +441,7 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
      * @return the Signature Base String
      * @see <a href="http://oauth.net/core/1.0#rfc.section.9.1.2">OAuth Core - 9.1.2.  Construct Request URL</a>
      */
-    public static String constructRequestURL(String url) {
+    static String constructRequestURL(String url) {
         int index = url.indexOf("?");
         if (-1 != index) {
             url = url.substring(0, index);
@@ -457,11 +464,13 @@ public class OAuthAuthorization implements Authorization, java.io.Serializable,
         return url;
     }
 
+    @Override
     public void setOAuthConsumer(String consumerKey, String consumerSecret) {
-        this.consumerKey = null != consumerKey ? consumerKey : "";
-        this.consumerSecret = null != consumerSecret ? consumerSecret : "";
+        this.consumerKey = consumerKey != null ? consumerKey : "";
+        this.consumerSecret = consumerSecret != null ? consumerSecret : "";
     }
 
+
     @Override
     public boolean equals(Object o) {
         if (this == o) return true;
