@@ -141,8 +141,6 @@ public class RssAction implements AJAXActionService {
             feeds = getAcceptedFeeds(urls, warnings);
         } catch (IllegalArgumentException | MalformedURLException e) {
             throw AjaxExceptionCodes.IMVALID_PARAMETER.create(e, e.getMessage());
-        } catch (IOException e) {
-            throw AjaxExceptionCodes.IO_ERROR.create(e, e.getMessage());
         } catch (JSONException e) {
             throw AjaxExceptionCodes.JSON_ERROR.create(e, e.getMessage());
         }
@@ -185,14 +183,15 @@ public class RssAction implements AJAXActionService {
                 @SuppressWarnings("unchecked") List<SyndContent> contents = entry.getContents();
                 boolean foundHtml = false;
                 for (SyndContent content : contents) {
-                    if ("html".equals(content.getType())) {
+                    String type = content.getType();
+                    if (null != type && (type.startsWith("htm") || type.startsWith("xhtm"))) {
                         foundHtml = true;
                         String htmlContent = preprocessor.process(content.getValue(), result);
                         result.setBody(htmlContent).setFormat("text/html");
                         break;
                     }
                     if (!foundHtml) {
-                        result.setBody(content.getValue()).setFormat(content.getType());
+                        result.setBody(content.getValue()).setFormat(type);
                     }
                 }
             }
@@ -336,7 +335,7 @@ public class RssAction implements AJAXActionService {
      * @param string The string to sanitise
      * @return The sanitised string if the {@link HtmlService} is available
      */
-    private static String sanitiseString(String string) {
+    private static String sanitiseString(String string) throws OXException {
         final HtmlService htmlService = Services.getService(HtmlService.class);
         if (htmlService == null) {
             LOG.warn("The HTMLService is unavailable at the moment, thus the RSS string '{}' might not be sanitised", string);
