@@ -49,22 +49,17 @@
 
 package com.openexchange.rss.util;
 
-import java.net.InetAddress;
-import java.net.URI;
-import java.net.URISyntaxException;
-import java.net.UnknownHostException;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.Set;
-
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.java.Strings;
 import com.openexchange.rss.osgi.Services;
 import com.openexchange.tools.HostList;
 
 /**
- *
+ * 
  * {@link RssProperties}
  *
  * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
@@ -97,7 +92,7 @@ public class RssProperties {
                         return HostList.valueOf(HOST_BLACKLIST_DEFAULT);
                     }
                     String prop = service.getProperty(HOST_BLACKLIST_KEY, HOST_BLACKLIST_DEFAULT);
-                    if (!Strings.isEmpty(prop)) {
+                    if (Strings.isNotEmpty(prop)) {
                         prop = prop.trim();
                     }
                     tmp = HostList.valueOf(prop);
@@ -141,7 +136,7 @@ public class RssProperties {
                         return toIntSet(PORT_WHITELIST_DEFAULT);
                     }
                     String prop = service.getProperty(PORT_WHITELIST_KEY, PORT_WHITELIST_DEFAULT);
-                    if (!Strings.isEmpty(prop)) {
+                    if (Strings.isNotEmpty(prop)) {
                         prop = prop.trim();
                     }
                     if (Strings.isEmpty(prop)) {
@@ -160,7 +155,7 @@ public class RssProperties {
         String[] tokens = Strings.splitByComma(prop);
         Set<Integer> tmp = new HashSet<Integer>(tokens.length);
         for (String token : tokens) {
-            if (!Strings.isEmpty(token)) {
+            if (Strings.isNotEmpty(token)) {
                 try {
                     tmp.add(Integer.valueOf(token.trim()));
                 } catch (NumberFormatException e) {
@@ -176,31 +171,13 @@ public class RssProperties {
      * <p>
      * The host name can either be a machine name, such as "<code>java.sun.com</code>", or a textual representation of its IP address.
      *
-     * @param uriString The URI (as String) of the rss feed
+     * @param scheme The url scheme; might be something like 'http', 'https', ...
+     * @param hostName The host name; either a machine name or a textual representation of its IP address
+     * @param port The port number
      * @return <code>true</code> if denied; otherwise <code>false</code>
      */
-    public static boolean isDenied(String uriString) {
-        try {
-        	URI uri = new URI(uriString);
-            return !isAllowed(uri.getPort()) || isBlacklisted(uri.getHost()) || !isAllowedScheme(uri.getScheme()) || !isValid(uri);
-        } catch (URISyntaxException e) {
-            org.slf4j.LoggerFactory.getLogger(RssProperties.class).debug("Given feed URL \"{}\" appears not to be valid.", uriString, e);
-            return true;
-        }
-    }
-
-    private static boolean isValid(URI uri) {
-        try {
-            InetAddress inetAddress = InetAddress.getByName(uri.getHost());
-            if (inetAddress.isAnyLocalAddress() || inetAddress.isSiteLocalAddress() || inetAddress.isLoopbackAddress() || inetAddress.isLinkLocalAddress()) {
-                org.slf4j.LoggerFactory.getLogger(RssProperties.class).debug("Given feed URL \"{}\" with destination IP {} appears not to be valid.", uri.toString(), inetAddress.getHostAddress());
-                return false;
-            }
-        } catch (UnknownHostException e) {
-            org.slf4j.LoggerFactory.getLogger(RssProperties.class).debug("Given feed URL \"{}\" appears not to be valid.", uri.toString(), e);
-            return false;
-        }
-        return true;
+    public static boolean isDenied(String scheme, String hostName, int port) {
+        return !isAllowed(port) || isBlacklisted(hostName) || !isAllowedScheme(scheme);
     }
 
     /**
@@ -258,7 +235,7 @@ public class RssProperties {
         if (schemes == null || schemes.length == 0) {
             return Collections.emptySet();
         }
-        return new HashSet<String>(Arrays.asList(schemes));
+        return new HashSet<>(Arrays.asList(schemes));
     }
 
     private static boolean isAllowedScheme(String scheme) {
