@@ -16,12 +16,7 @@
 
 package twitter4j.examples.geo;
 
-import twitter4j.GeoLocation;
-import twitter4j.Place;
-import twitter4j.SimilarPlaces;
-import twitter4j.Twitter;
-import twitter4j.TwitterException;
-import twitter4j.TwitterFactory;
+import twitter4j.*;
 
 /**
  * Locates places near the given coordinates which are similar in name.
@@ -55,7 +50,7 @@ public final class GetSimilarPlaces {
                 for (Place place : places) {
                     System.out.println("id: " + place.getId() + " name: " + place.getFullName() + " name: " + place.getFullName());
                     Place[] containedWithinArray = place.getContainedWithIn();
-                    if (null != containedWithinArray && containedWithinArray.length != 0) {
+                    if (containedWithinArray != null && containedWithinArray.length != 0) {
                         System.out.println("  contained within:");
                         for (Place containedWithinPlace : containedWithinArray) {
                             System.out.println("  id: " + containedWithinPlace.getId() + " name: " + containedWithinPlace.getFullName());
